---
title: "There Is No Such Thing as Free Speech"
author: "Stanley Fish"
image: img/stanley-fish.jpg
era: "Twentieth Century"
topic: "Free Speech"
draft: false
---

*The following is an excerpt from the essay that shares the title of the book: [“There’s No Such Thing As Free Speech”](https://www.amazon.co.uk/Theres-Such-Thing-Free-Speech-ebook/dp/B004UP9AN4/ref=sr_1_11?keywords=stanley+fish&qid=1572688614&s=digital-text&sr=1-11), by Stanley Fish.*

**There’s No Such Thing As Free Speech**

Lately, many on the liberal and progressive left have been disconcerted to find that words, phrases, and concepts thought to be their property and generative of their politics have been appropriated by the forces of neoconservatism. This is particularly true of the concept of free speech, for in recent years First Amendment rhetoric has been used to justify policies and actions the left finds problematical if not abhorrent: pornography, sexist language, campus hate speech. How has this happened? The answer I shall give in this essay is that abstract concepts like free speech do not have any “natural” content but are filled with whatever content and direction one can manage to put into them. “Free speech” is just the name we give to verbal behavior that serves the substantive agendas we wish to advance; and we give our preferred verbal behaviors that name when we can, when we have the power to do so, because in the rhetoric of American life, the label “free speech” is the one you want your favorites to wear. Free speech, in short, is not an independent value but a political prize, and if that prize has been captured by a politics opposed to yours, it can no longer be invoked in ways that further your purposes, for it is now an obstacle to those purposes. This is something that the liberal left has yet to understand, and what follows is an attempt to pry its members loose from a vocabulary that may now be a disservice to them.

Not far from the end of his {{< reltab title="Areopagitica," url="/reading/areopagitica/" >}} and after having celebrated the virtues of toleration and unregulated publication in passages that find their way into every discussion of free speech and the First Amendment, John Milton catches himself up short and says, of course I didn’t mean Catholics, them we exterminate:

> I mean not tolerated popery, and open superstition, which as it extirpates all religious and civil supremacies, so itself should be extirpate . . . that also which is impious or evil absolutely against faith or manners no law can possibly permit that intends not to unlaw itself.

Notice that Milton is not simply stipulating a single exception to a rule generally in place; the kinds of utterance that might be regulated and even prohibited on pain of trial and punishment constitute an open set; popery is named only as a particularly perspicuous instance of the advocacy that cannot be tolerated. No doubt there are other forms of speech and action that might be categorized as “open superstitions” or as subversive of piety, faith, and manners, and presumably these too would be candidates for “extirpation.” Nor would Milton think himself culpable for having failed to provide a list of unprotected utterances. The list will fill itself out as utterances are put to the test implied by his formulation: would this form of speech or advocacy, if permitted to flourish, tend to undermine the very purposes for which our society is constituted? One cannot answer this question with respect to a particular utterance in advance of its emergence on the world’s stage; rather, one must wait and ask the question in the full context of its production and (possible) dissemination. It might appear that the result would be ad hoc and unprincipled, but for Milton the principle inheres in the core values in whose name individuals of like mind came together in the first place. Those values, which include the search for truth and the promotion of virtue, are capacious enough to accommodate a diversity of views. But at some point—again impossible of advance specification—capaciousness will threaten to become shapelessness, and at that point fidelity to the original values will demand acts of extirpation.

I want to say that all affirmations of freedom of expression are like Milton’s, dependent for their force on an exception that literally carves out the space in which expression can then emerge. I do not mean that expression (saying something) is a realm whose integrity is sometimes compromised by certain restrictions but that restriction, in the form of an underlying articulation of the world that necessarily (if silently) negates alternatively possible articulations, is constitutive of expression. Without restriction, without an inbuilt sense of what it would be meaningless to say or wrong to say, there could be no assertion and no reason for asserting it. The exception to unregulated expression is not a negative restriction but a positive hollowing out of value—we are for this, which means we are against that—in relation to which meaningful assertion can then occur. It is in reference to that value—constituted as all values are by an act of exclusion—that some forms of speech will be heard as (quite literally) intolerable. Speech, in short, is never a value in and of itself but is always produced within the precincts of some assumed conception of the good to which it must yield in the event of conflict. When the pinch comes (and sooner or later it will always come) and the institution (be it church, state, or university) is confronted by behavior subversive of its core rationale, it will respond by declaring “of course we mean not tolerated———, that we extirpate,” not because an exception to a general freedom has suddenly and contradictorily been announced, but because the freedom has never been general and has always been understood against the background of an originary exclusion that gives it meaning….

…I think… people cling to First Amendment pieties because they do not wish to face… the realization (at which I have already hinted) that decisions about what is and is not protected in the realm of expression will rest not on principle or firm doctrine but on the ability of some persons to interpret—recharacterize or rewrite—principle and doctrine in ways that lead to the protection of speech they want heard and the regulation of speech they want heard and the regulation of speech they want silenced. (That is how George Bush can argue for flag-burning statutes and against campus hate-speech codes.) When the First Amendment is successfully invoked, the result is not a victory for free speech in the face of a challenge from politics but a *political victory* won by the party that has managed to wrap its agenda in the mantle of free speech.

It is from just such a conclusion — a conclusion that would put politics inside the First Amendment — that commentators recoil, saying things like “This could render the First Amendment a dead letter,” or “This would leave us with no normative guidance in determining when and what speech to protect,” or “This effaces the distinction between speech and action,” or “This is incompatible with any viable notion of freedom of expression.” To these statements (culled more or less at random from recent law review pieces) I would reply that the First Amendment has always been a dead letter if one understood its “liveness” to depend on the identification and protection of a realm of “mere” expression distinct from the realm of regulatable conduct; the distinction between speech and action has always been effaced in principle, although in practice it can take whatever form the prevailing political conditions mandate; we have never had any normative guidance for marking off protected from unprotected speech; rather, the guidance we have has been fashioned (and refashioned) in the very political struggles over which it then (for a time) presides. In short, the name of the game has always been politics, even when (indeed, especially when) it is played by stigmatizing politics as the area to be avoided.

In saying this, I would not be heard as arguing either for or against regulation and speech codes as a matter of general principle. Instead my argument turns away from general principle to the pragmatic (anti)principle of considering each situation as it emerges. The question of whether or not to regulate will always be a local one, and we can not rely on abstractions that are either empty of content or filled with the content of some partisan agenda to generate a “principled” answer. Instead we must consider in every case what is at stake and what are the risks and gains of alternative courses of action. In the course of this consideration many things will be of help, but among them will not be phrases like “freedom of speech” or “the right of individual expression,” because, as they are used now, these phrases tend to obscure rather than clarify our dilemmas. Once they are deprived of their talismanic force, once it is no longer strategically effective simply to invoke them in the act of walking away from a problem, the conversation could continue in directions that are now blocked by a First Amendment absolutism that has only been honored in the breach anyway…

…No such thing as free (nonideologically constrained) speech; no such thing as a public forum purged of ideological pressures or exclusions. That’s my thesis, and waiting at the end (really at the beginning) of it is, as my respondents have said, politics. Not, however, politics as the dirty word it becomes in most First Amendment discussions, but politics as the attempt to implement some partisan vision. I place the word “vision” after “partisan” so as to forestall the usual reading of partisan as “unprincipled,” the reading Post attributes to me when he finds me “writing on the assumption that there is some implicit and mutually exclusive dichotomy between politics and principle.” In fact, my argument is exactly the reverse: since it is only from within a commitment to some particular (not abstract) agenda that one feels the deep urgency we identify as “principled,” politics is the source of principle, not its opposite. When two agendas square off, the contest is never between politics and principle but between two forms of politics, or, if you prefer, two forms of principle…

…It is a counsel that follows from the thesis that there is no such thing as free speech, which is not, after all, a thesis as startling or corrosive as may first have seemed. It merely says that there is no class of utterances separable from the world of conduct and that therefore the identification of some utterances as members of that nonexistent class will always be evidence that a political line has been drawn rather than a line that denies politics entry into the forum of public discourse. It is the job of the First Amendment to mark out an area in which competing views can be considered without state interference; but if the very marking out of that area is itself an interference (as it always will be), First Amendment jurisprudence is inevitably self-defeating and subversive of its own aspirations. That’s the bad news. The good news is that precisely because speech is never “free” in the two senses required—free of consequences and free from state pressure—speech always matters, is always doing work; because everything we say impinges on the world in ways indistinguishable from the effects of physical action, we must take responsibility for our verbal performances—all of them—and not assume that they are being taken cares of by a clause in the Constitution. Of course, with responsibility comes risks, but they have always been our risks, and no doctrine of free speech has ever insulated us from them. They are the risks, respectively, of permitting speech that does obvious harm and of shutting off speech in ways that might deny us the benefit of Joyce’s Ulysses or Lawrence’s Lady Chatterly’s Lover or Titian’s paintings. Nothing, I repeat, can insulate us from those risks. (If there is no normative guidance in determining when and what speech to protect, there is no normative guidance in determining what is art—like free speech a category that includes everything and nothing—and what is obscenity.) Moreover, nothing can provide us with a principle for deciding which risk in the long run is the best to take. I am persuaded that at the present moment, right now, the risk of not attending to hate speech is greater than the risk that by regulating it we will deprive ourselves of valuable voices and insights or slide down the slippery slope toward tyranny. This is a judgment for which I can offer reasons but no guarantees. All I am saying is that the judgments of those who would come down on the other side carry no guarantees either. They urge us to put our faith in apolitical abstractions, but the abstractions they invoke—the marketplace of ideas, speech alone, speech itself—only come in political guises, and therefore in trusting to them we fall (unwittingly) under the sway of the very forces we wish to keep at bay. It is not that there are no choices to make or means of making them; it is just that the choices as well as the means are inextricable from the din and confusion of partisan struggle. There is no safe place.